pub struct ContractSyncService<N: AztecNode> { /* private fields */ }Expand description
Service that ensures contracts’ private state is synced before execution.
Maintains a cache of already-synced contracts to avoid redundant sync operations within a transaction.
Implementations
Sourceimpl<N: AztecNode> ContractSyncService<N>
impl<N: AztecNode> ContractSyncService<N>
pub fn new(node: Arc<N>, note_store: Arc<NoteStore>) -> Self
Sourcepub async fn ensure_contract_synced<F, Fut>(
&self,
contract_address: &AztecAddress,
scopes: &[AztecAddress],
anchor_block_hash: &str,
utility_executor: F,
) -> Result<(), Error>
pub async fn ensure_contract_synced<F, Fut>( &self, contract_address: &AztecAddress, scopes: &[AztecAddress], anchor_block_hash: &str, utility_executor: F, ) -> Result<(), Error>
Ensure a contract’s private state is synchronized.
If the contract has already been synced for the given scopes in the current anchor block, this is a no-op.
pub async fn ensure_contract_synced_with<F, Fut>( &self, contract_address: &AztecAddress, scopes: &[AztecAddress], anchor_block_hash: &str, utility_executor: &F, ) -> Result<(), Error>